import type { LoginResult } from '@/types/member'
import { http } from '@/utils/http'
import { useMemberStore } from '@/stores'

type LoginWxMinParams = {
  code: string
  encryptedData?: string
  iv?: string
}
/**
 * 小程序登录
 * @param data 请求参数
 */
export const postLoginWxMinAPI = (data: LoginWxMinParams) => {
  return http<LoginResult>({
    method: 'POST',
    url: '/login/wxMin',
    data,
  })
}

/**
 * 小程序登录_内测版
 * @param phoneNumber 模拟手机号码
 */
export const postLoginWxMinSimpleAPI = (phoneNumber: string) => {
  return http<LoginResult>({
    method: 'POST',
    url: '/login/wxMin/simple',
    data: {
      phoneNumber,
    },
  })
}

type LoginParams = {
  username: string
  password: string
  captcha: string
  keep: boolean
  loading: boolean
  captcha_id: string
}
/**
 * 传统登录-用户名+密码
 * @param data 请求参数
 */
export const postLoginAPI = (data: LoginParams) => {
  return http<{ userInfo: LoginResult }>({
    method: 'POST',
    url: '/admin/index/login',
    data,
  })
}

/**
 * 获取验证码图片
 */
export const getVerifyCodeImg = (captcha_id: string) => {
  return http<any>({
    method: 'GET',
    url: `/api/common/captcha?server=1&id=${captcha_id}&m=` + Math.random(),
    responseType: 'arraybuffer', //设置响应类型
  })
}
/**
 * 刷新token
 * @param data 请求参数
 */
export const refreshToken = () => {
  const memberStore = useMemberStore()
  const refreshToken = memberStore.profile?.refreshToken

  return http<{ token: string; type: string }>({
    method: 'POST',
    url: '/api/common/refreshToken',
    data: { refresh_token: refreshToken },
  })
}
